ftw.notification.email
======================

This package is an extension for ``ftw.notification.base`` providing
email notification after editing a content.

See ``ftw.notification.base``_ for further details.


Usage
=====

- Add ``ftw.notification.email`` to your buildout configuration:

::

    [instance]
    eggs +=
        ftw.notification.email

- Install the generic setup profile of the package


Links
=====

- Main github project repository: https://github.com/4teamwork/ftw.notification.email
- Issue tracker: https://github.com/4teamwork/ftw.notification.email/issues
- Package on pypi: http://pypi.python.org/pypi/ftw.notification.email
- Continuous integration: https://jenkins.4teamwork.ch/search/?q=ftw.notification.email



Copyright
=========

This package is copyright by `4teamwork <http://www.4teamwork.ch/>`_.

``ftw.notification.email`` is licensed under GNU General Public License, version 2.


.. _ftw.notification.base: https://github.com/4teamwork/ftw.notification.base
